#
# spec file for package python-typogrify
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-typogrify
Version:        2.1.0
Release:        1.1
Summary:        Typography related template filters for Django & Jinja2 applications
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/mintchaos/typogrify
Source:         https://files.pythonhosted.org/packages/source/t/typogrify/typogrify-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module smartypants >= 1.8.3}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-smartypants >= 1.8.3
BuildArch:      noarch
%python_subpackages

%description
This application provides a set of custom filters for the Django template system
which automatically apply various transformations to plain text in order to yield
typographically-improved HTML.

%prep
%setup -q -n typogrify-%{version}
# remove useless shebang and executable bit
sed -i '1d' \
	typogrify/packages/titlecase/__init__.py \
	typogrify/packages/titlecase/tests.py
chmod -x typogrify/packages/titlecase/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{_prefix}

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib} PYTHONDONTWRITEBYTECODE=1
$python -mdoctest -v typogrify/filters.py
}

%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitelib}/typogrify-%{version}.dist-info
%{python_sitelib}/typogrify

%changelog
* Mon Jan 13 2025 Benoît Monin <benoit.monin@gmx.fr>
- update to version 2.1.0:
  * Add ability to select which filters are applied
  * Package via pyproject instead of Setuptools
  * Improve testing, linting, and CI tooling
  * Drop support for Python < 3.9
- update the build requirements to build with pip and hatchling
- remove executable bit of typogrify/packages/titlecase/__init__.py
- restrict the list of packaged files to typogrify only
* Thu Jul  6 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Jan  4 2021 Markéta Machová <mmachova@suse.com>
- spec-cleaner to pass the Factory checks
* Mon Nov 16 2020 Matej Cepl <mcepl@suse.com>
- Enable tests.
* Mon May  8 2017 benoit.monin@gmx.fr
- convert the package to singlespec
- call fdupes to fix duplicated files
* Tue Sep 23 2014 benoit.monin@gmx.fr
- update to version 2.0.7:
  * 2.0.4: moving titlecase into the project
  * 2.0.2, 2.0.3: adding support for custom ignore tags
- remove useless shebang on python files
- add package documentation
- add the requires as buildrequires to guarantee they are available
* Wed Jan  8 2014 benoit.monin@gmx.fr
- update to upstream version 2.0.1:
  * add Python 3 compatibility
  * rectify deprecated function calls
* Fri Dec 27 2013 benoit.monin@gmx.fr
- switch from distribute to setuptools
- remove useless CFLAGS="%%{optflags}"
* Wed Mar 27 2013 benoit.monin@gmx.fr
- initial package with version 2.0.0
